"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const winston_1 = require("winston");
const path = __importStar(require("path"));
/**
 * Creates an instance of the winston logger that writes to stdout and a file
 * @param options A file to write to or an options object
 */
exports.loggerFactory = (options) => {
    const opts = typeof options === 'string' ? {} : options;
    const logPath = (opts && opts.path) || process.env.LOG_PATH || '';
    const logName = typeof options === 'string'
        ? options
        : (opts && opts.name) || process.env.LOG_FILE || 'salesforce-api.log';
    const logLevel = (opts && opts.level) || process.env.LOG_LEVEL || 'info';
    const f = winston_1.format.combine(winston_1.format.splat(), winston_1.format.timestamp(), winston_1.format.printf(info => `${info.timestamp} - ${info.level}: ${info.message}`));
    const logTransports = [
        new winston_1.transports.Console({
            format: winston_1.format.combine(winston_1.format.colorize(), f),
        }),
        new winston_1.transports.File({ filename: path.join(logPath, logName) }),
    ];
    const logOptions = {
        transports: logTransports,
        level: logLevel,
        format: f,
    };
    return winston_1.createLogger(logOptions);
};
//# sourceMappingURL=logger.factory.js.map