"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const grpc = __importStar(require("grpc"));
const path = __importStar(require("path"));
const salesforce_service_1 = require("../salesforce.service");
const logger_factory_1 = require("../logger.factory");
const util_1 = require("../util");
const proto_loader_1 = require("@grpc/proto-loader");
const sf_api_shared_1 = require("@shingo/sf-api-shared");
const fp_1 = require("../fp");
// tslint:disable:variable-name
const makeCall = util_1.handleUnary(logger_factory_1.loggerFactory());
class SalesforceMicroservice {
    constructor(env, sfservice = new salesforce_service_1.SalesforceService(env.SF_URL, env.SF_ENV, env.SF_USER, env.SF_PASS)) {
        this.sfservice = sfservice;
        this.Query = makeCall('query', fp_1.pipe(sf_api_shared_1.validateInput(sf_api_shared_1.QueryRequest), req => req.then(q => this.sfservice.query(q))));
        this.Retrieve = makeCall('retrieve', fp_1.pipe(sf_api_shared_1.validateInput(sf_api_shared_1.IdRequest), req => req.then(id => this.sfservice.retrieve(id))));
        this.Create = makeCall('create', fp_1.pipe(sf_api_shared_1.validateInput(sf_api_shared_1.RecordsRequest), req => req.then(r => this.sfservice.create(r))));
        this.Update = makeCall('update', fp_1.pipe(sf_api_shared_1.validateInput(sf_api_shared_1.RecordsRequest), req => req.then(r => this.sfservice.update(r))));
        this.Delete = makeCall('delete', fp_1.pipe(sf_api_shared_1.validateInput(sf_api_shared_1.IdRequest), req => req.then(id => this.sfservice.delete(id))));
        this.Upsert = makeCall('upsert', fp_1.pipe(sf_api_shared_1.validateInput(sf_api_shared_1.UpsertRequest), req => req.then(u => this.sfservice.upsert(u))));
        this.Describe = makeCall('describe', fp_1.pipe(sf_api_shared_1.validateInput(sf_api_shared_1.DescribeRequest), req => req.then(d => this.sfservice.describe(d.object))));
        this.Search = makeCall('search', fp_1.pipe(sf_api_shared_1.validateInput(sf_api_shared_1.SearchRequest), req => req.then(s => this.sfservice.search(s))));
        const protoFile = path.join(__dirname, '../proto', 'sf_services.proto');
        const options = {
            keepCase: true,
            longs: String,
            enums: String,
            defaults: true,
            oneofs: true,
        };
        const packageDefinition = proto_loader_1.loadSync(protoFile, options);
        const protoDescriptor = grpc.loadPackageDefinition(packageDefinition)
            .sfservices;
        this.service = protoDescriptor.SalesforceMicroservice.service;
    }
}
exports.SalesforceMicroservice = SalesforceMicroservice;
//# sourceMappingURL=salesforce.microservice.js.map