import { Connection } from 'jsforce';
import { ServiceError, status as Status, Metadata, handleUnaryCall } from 'grpc';
import { Logger } from 'winston';
import { RecordsRequest } from '@shingo/sf-api-shared';
/**
 * Authenticates a connection to salesforce and calls a function with the logged in connection
 * @param username Salesforce username
 * @param password Salesforce password
 * @param connection JSForce connection object
 * @param fn The function to run
 */
export declare const runQuery: (username: string, password: string, connection: Connection) => <T>(fn: (conn: Connection) => Promise<T>) => Promise<T>;
export declare class SError extends Error implements ServiceError {
    code?: Status;
    metadata?: Metadata;
    constructor(error: Error | object, status?: Status);
}
/**
 * Handles a GRPC unary request
 * @param logger Logger instance
 * @param name Function name for logging
 * @param fn Handler function implementation
 */
export declare const handleUnary: (logger: Logger) => <Req, Res>(name: string, fn: (req: Req) => Promise<Res>) => handleUnaryCall<Req, Res>;
export declare const getRecords: (req: RecordsRequest, omit?: string[]) => (string | number | import("@shingo/sf-api-shared/build/sf_services.interface").JSONObj | import("@shingo/sf-api-shared/build/sf_services.interface").JSONArray)[];
export declare const deepClean: <T extends object, K extends string | number | symbol>(o: T, ...keys: K[]) => Pick<T, Exclude<keyof T, K>>;
//# sourceMappingURL=util.d.ts.map